@@ -48,8 +48,6 @@ module.exports = [
   ['1.2.*', '1.2.3'],
   ['1.2.* || 2.*', '2.1.3'],
   ['1.2.* || 2.*', '1.2.3'],
-  ['1.2.* || 2.*', '1.2.3'],
-  ['*', '1.2.3'],
   ['2', '2.1.2'],
   ['2.3', '2.3.1'],
   ['~2.4', '2.4.0'], // >=2.4.0 <2.5.0
@@ -82,5 +80,5 @@ module.exports = [
   ['^0.1.0 || ~3.0.1 || 5.0.0', '1.0.0beta', true],
   ['^0.1.0 || ~3.0.1 || 5.0.0', '5.0.0-0', true],
   ['^0.1.0 || ~3.0.1 || >4 <=5.0.0', '3.5.0'],
-  ['0.7.x', '0.7.2-beta', { includePrerelease: true }]
+  ['0.7.x', '0.7.2-beta', { includePrerelease: true }],
 ]
