@@ -8,7 +8,7 @@ test('strict vs loose version numbers', (t) => {
     ['01.02.03', '1.2.3'],
     ['1.2.3-beta.01', '1.2.3-beta.1'],
     ['   =1.2.3', '1.2.3'],
-    ['1.2.3foo', '1.2.3-foo']
+    ['1.2.3foo', '1.2.3-foo'],
   ].forEach((v) => {
     const loose = v[0]
     const strict = v[1]
