@@ -7,14 +7,14 @@ test('sorting', (t) => {
     '1.2.3+0',
     '1.2.3',
     '5.9.6',
-    '0.1.2'
+    '0.1.2',
   ]
   const rsorted = [
     '5.9.6',
     '1.2.3+1',
     '1.2.3+0',
     '1.2.3',
-    '0.1.2'
+    '0.1.2',
   ]
   t.same(rsort(list), rsorted)
   t.end()
