@@ -2,6 +2,7 @@ const t = require('tap')
 const valid = require('../../functions/valid')
 const SemVer = require('../../classes/semver')
 const invalidVersions = require('../fixtures/invalid-versions')
+const { MAX_SAFE_INTEGER } = require('../../internal/constants')
 
 t.test('returns null instead of throwing when presented with garbage', t => {
   t.plan(invalidVersions.length)
@@ -17,3 +18,12 @@ t.test('validate a version into a SemVer object', t => {
   t.equal(valid('4.2.0foo', { loose: true }), '4.2.0-foo', 'looseness as an option')
   t.end()
 })
+
+t.test('long build id', t => {
+  const longBuild = '-928490632884417731e7af463c92b034d6a78268fc993bcb88a57944'
+  const shortVersion = '1.1.1'
+  const longVersion = `${MAX_SAFE_INTEGER}.${MAX_SAFE_INTEGER}.${MAX_SAFE_INTEGER}`
+  t.equal(valid(shortVersion + longBuild), shortVersion + longBuild)
+  t.equal(valid(longVersion + longBuild), longVersion + longBuild)
+  t.end()
+})
