@@ -1,12 +1,12 @@
 const main = () => {
   const t = require('tap')
-  const {spawn} = require('child_process')
+  const { spawn } = require('child_process')
   t.plan(2)
   t.test('without env set', t => {
-    const c = spawn(process.execPath, [__filename, 'child'], {env: {
+    const c = spawn(process.execPath, [__filename, 'child'], { env: {
       ...process.env,
-      NODE_DEBUG: ''
-    }})
+      NODE_DEBUG: '',
+    } })
     const err = []
     c.stderr.on('data', chunk => err.push(chunk))
     c.on('close', (code, signal) => {
@@ -17,10 +17,10 @@ const main = () => {
     })
   })
   t.test('with env set', t => {
-    const c = spawn(process.execPath, [__filename, 'child'], {env: {
+    const c = spawn(process.execPath, [__filename, 'child'], { env: {
       ...process.env,
-      NODE_DEBUG: 'semver'
-    }})
+      NODE_DEBUG: 'semver',
+    } })
     const err = []
     c.stderr.on('data', chunk => err.push(chunk))
     c.on('close', (code, signal) => {
@@ -33,4 +33,8 @@ const main = () => {
   t.end()
 }
 
-if (process.argv[2] === 'child') { require('../../internal/debug')('hello, world') } else { main() }
+if (process.argv[2] === 'child') {
+  require('../../internal/debug')('hello, world')
+} else {
+  main()
+}
